/* fs/ngffs/sysfiles.h
 *
 * NGFFS, next generation flash file system
 *
 * Copyright (C) 2004-2007 TomTom BV <http://www.tomtom.com/>
 * Author: Koen Martens <kmartens@sonologic.nl>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#ifndef __FS_NGFFS_SYSFILES_H
#define __FS_NGFFS_SYSFILES_H

#define NGFFS_CAL_LEN		16
#define NGFFS_CAL_OFS		0x104
#define NGFFS_CAL_NAME		"cal"

#define NGFFS_ID_LEN		12
#define NGFFS_ID_OFS		0x114
#define NGFFS_ID_NAME		"id"

#define NGFFS_MAC_LEN		6
#define NGFFS_MAC_OFS		0x120
#define NGFFS_MAC_NAME		"mac"

#define NGFFS_IMEI_LEN		16
#define NGFFS_IMEI_OFS		0x300
#define NGFFS_IMEI_NAME		"imei"

/* powertable is not used */
#define MAX_PT_ENTRIES		1
#define NGFFS_BTCAL_LEN		2+((2+2)*(MAX_PT_ENTRIES + 1))
#define NGFFS_BTCAL_OFS		0x14c
#define NGFFS_BTCAL_NAME	"btcal"

#define NGFFS_SPK_LEN		2
#define NGFFS_SPK_OFS		0x204
#define NGFFS_SPK_NAME		"spk"

#define NGFFS_MIC_LEN		2
#define NGFFS_MIC_OFS		0x206
#define NGFFS_MIC_NAME		"mic"

#define NGFFS_MEMSIZEMB_LEN		2
#define NGFFS_MEMSIZEMB_OFS		0x208
#define NGFFS_MEMSIZEMB_NAME		"memsizemb"

#define NGFFS_LCMTYPE_LEN		2
#define NGFFS_LCMTYPE_OFS		0x20a
#define NGFFS_LCMTYPE_NAME		"lcmtype"

#define NGFFS_BATTCAL_LEN	6
#define NGFFS_BATTCAL_OFS	0x20c
#define NGFFS_BATTCAL_NAME	"battcal"

#define NGFFS_FEATURE_LEN		8
#define NGFFS_FEATURE_OFS		0x218
#define NGFFS_FEATURE_NAME		"feature"

#define NGFFS_GPRSMODEMTYPE_LEN		2
#define NGFFS_GPRSMODEMTYPE_OFS		0x220
#define NGFFS_GPRSMODEMTYPE_NAME	"gprsmodemtype"

#define NGFFS_FMTRANSMITTERTYPE_LEN	2
#define NGFFS_FMTRANSMITTERTYPE_OFS	0x222
#define NGFFS_FMTRANSMITTERTYPE_NAME	"fmtransmittertype"

#define NGFFS_BAROTYPE_LEN		2
#define NGFFS_BAROTYPE_OFS		0x224
#define NGFFS_BAROTYPE_NAME		"barotype"

#define NGFFS_ACCELEROMETERTYPE_LEN	2
#define NGFFS_ACCELEROMETERTYPE_OFS	0x226
#define NGFFS_ACCELEROMETERTYPE_NAME	"accelerometertype"

#define NGFFS_GYROTYPE_LEN		2
#define NGFFS_GYROTYPE_OFS		0x228
#define NGFFS_GYROTYPE_NAME		"gyrotype"

#define NGFFS_GPRSANTENNATYPE_LEN	2
#define NGFFS_GPRSANTENNATYPE_OFS	0x22a
#define NGFFS_GPRSANTENNATYPE_NAME	"gprsantennatype"

#define NGFFS_ACCCAL_LEN	24
#define NGFFS_ACCCAL_OFS	0x22c
#define NGFFS_ACCCAL_NAME	"acccal"

#define NGFFS_GYRCAL_LEN	16
#define NGFFS_GYRCAL_OFS	0x244
#define NGFFS_GYRCAL_NAME	"gyrcal"

#define NGFFS_VER_LEN		16
#define NGFFS_VER_OFS		0x3fff0
#define NGFFS_VER_NAME		"bootver"

#define NGFFS_SYSFILES		20

#ifndef NGFFS_SYSFILE
extern struct ngffs_sysfile ngffs_sysfiles[];
#else /* NGFFS_SYSFILE */
struct ngffs_sysfile ngffs_sysfiles[] = {
	{ NGFFS_CAL_LEN   , NGFFS_CAL_OFS   , NGFFS_CAL_NAME    },
	{ NGFFS_ID_LEN 	  , NGFFS_ID_OFS    , NGFFS_ID_NAME     },
	{ NGFFS_MAC_LEN	  , NGFFS_MAC_OFS   , NGFFS_MAC_NAME    },
	{ NGFFS_IMEI_LEN  , NGFFS_IMEI_OFS  , NGFFS_IMEI_NAME   },
	{ NGFFS_BTCAL_LEN , NGFFS_BTCAL_OFS , NGFFS_BTCAL_NAME  },
	{ NGFFS_SPK_LEN	  , NGFFS_SPK_OFS   , NGFFS_SPK_NAME    },
	{ NGFFS_MIC_LEN   , NGFFS_MIC_OFS   , NGFFS_MIC_NAME    },
	{ NGFFS_MEMSIZEMB_LEN		, NGFFS_MEMSIZEMB_OFS		, NGFFS_MEMSIZEMB_NAME    },
	{ NGFFS_LCMTYPE_LEN		, NGFFS_LCMTYPE_OFS		, NGFFS_LCMTYPE_NAME    },
	{ NGFFS_BATTCAL_LEN,NGFFS_BATTCAL_OFS,NGFFS_BATTCAL_NAME},
	{ NGFFS_FEATURE_LEN		, NGFFS_FEATURE_OFS		, NGFFS_FEATURE_NAME},
	{ NGFFS_GPRSMODEMTYPE_LEN	, NGFFS_GPRSMODEMTYPE_OFS	, NGFFS_GPRSMODEMTYPE_NAME},
	{ NGFFS_FMTRANSMITTERTYPE_LEN   , NGFFS_FMTRANSMITTERTYPE_OFS	, NGFFS_FMTRANSMITTERTYPE_NAME},
	{ NGFFS_BAROTYPE_LEN		, NGFFS_BAROTYPE_OFS   		, NGFFS_BAROTYPE_NAME},
	{ NGFFS_ACCELEROMETERTYPE_LEN   , NGFFS_ACCELEROMETERTYPE_OFS   , NGFFS_ACCELEROMETERTYPE_NAME},
	{ NGFFS_GYROTYPE_LEN   		, NGFFS_GYROTYPE_OFS   		, NGFFS_GYROTYPE_NAME},
	{ NGFFS_GPRSANTENNATYPE_LEN	, NGFFS_GPRSANTENNATYPE_OFS	, NGFFS_GPRSANTENNATYPE_NAME},
	{ NGFFS_ACCCAL_LEN, NGFFS_ACCCAL_OFS, NGFFS_ACCCAL_NAME },
	{ NGFFS_GYRCAL_LEN, NGFFS_GYRCAL_OFS, NGFFS_GYRCAL_NAME },
	{ NGFFS_VER_LEN   , NGFFS_VER_OFS   , NGFFS_VER_NAME    }
};
#endif /* NGFFS_SYSFILE */

#endif /* __FS_NGFFS_SYSFILES_H */

/* EOF */
